星际穿越 (豆瓣)
Description: 星际穿越电影简介和剧情介绍,星际穿越影评、图片、预告片、影讯、论坛、在线购票
Keywords: 星际穿越,Interstellar,星际穿越影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.10豆瓣电影Top250

# 星际穿越 Interstellar (2014)

更新描述或海报

导演: 克里斯托弗·诺兰
编剧: 乔纳森·诺兰 / 克里斯托弗·诺兰
主演: 马修·麦康纳 / 安妮·海瑟薇 / 杰西卡·查斯坦 / 麦肯吉·弗依 / 卡西·阿弗莱克 / 迈克尔·凯恩 / 马特·达蒙 / 提莫西·查拉梅 / 艾伦·伯斯汀 / 约翰·利思戈 / 韦斯·本特利 / 大卫·吉亚西 / 比尔·欧文 / 托弗·戈瑞斯 / 科莱特·沃夫 / 弗朗西斯·X.麦卡蒂 / 安德鲁·博尔巴 / 乔什·斯图沃特 / 莱雅·卡里恩斯 / 利亚姆·迪金森 / 杰夫·赫普内尔 / 伊莱耶斯·加贝尔 / 布鲁克·史密斯 / 大卫·奥伊罗 / 威廉姆·德瓦内 / 拉什·费加 / 格里芬·弗雷泽 / 弗洛拉·诺兰
类型: 剧情 / 科幻 / 冒险
制片国家/地区: 美国 / 英国 / 加拿大
语言: 英语
上映日期: 2014-11-12(中国大陆) / 2020-08-02(中国大陆重映) / 2014-11-07(美国)
片长: 169分钟
又名: 星际启示录(港) / 星际效应(台) / 星际空间 / 星际之间 / 星际远航 / 星际 / Flora's Letter
IMDb: tt0816692
官方小站: 《星际穿越》电影专题
豆瓣评分
引用
9.4
1693781人评价
5星
74.4%
4星
21.2%
3星
3.8%
2星
0.4%
1星
0.2%
好友评分
你关注的人看过这部作品的平均分
8.0
6人评价
好于 99% 科幻片
好于 99% 冒险片
我看过这部电影 2020-07-12 修改
我的评价:
推荐

## 星际穿越的剧情简介 · · · · · ·

近未来的地球黄沙遍野，小麦、秋葵等基础农作物相继因枯萎病灭绝，人类不再像从前那样仰望星空，放纵想象力和灵感的迸发，而是每日在沙尘暴的肆虐下倒数着所剩不多的光景。在家务农的前NASA宇航员库珀（马修·麦康纳 Matthew McConaughey 饰）接连在女儿墨菲（麦肯吉·弗依 Mackenzie Foy 饰）的书房发现奇怪的重力场现象，随即得知在某个未知区域内前NASA成员仍秘密进行一个拯救人类的计划。多年以前土星附近出现神秘虫洞，NASA借机将数名宇航员派遣到遥远的星系寻找适合居住的星球。在布兰德教授（迈克尔·凯恩 Michael Caine 饰）的劝说下，库珀忍痛告别了女儿，和其他三名专家教授女儿艾米莉亚·布兰德（安妮·海瑟薇 Anne Hathaway 饰）、罗米利（大卫·吉雅西 David Gyasi 饰）、多伊尔（韦斯·本特利 Wes B... (展开全部) 近未来的地球黄沙遍野，小麦、秋葵等基础农作物相继因枯萎病灭绝，人类不再像从前那样仰望星空，放纵想象力和灵感的迸发，而是每日在沙尘暴的肆虐下倒数着所剩不多的光景。在家务农的前NASA宇航员库珀（马修·麦康纳 Matthew McConaughey 饰）接连在女儿墨菲（麦肯吉·弗依 Mackenzie Foy 饰）的书房发现奇怪的重力场现象，随即得知在某个未知区域内前NASA成员仍秘密进行一个拯救人类的计划。多年以前土星附近出现神秘虫洞，NASA借机将数名宇航员派遣到遥远的星系寻找适合居住的星球。在布兰德教授（迈克尔·凯恩 Michael Caine 饰）的劝说下，库珀忍痛告别了女儿，和其他三名专家教授女儿艾米莉亚·布兰德（安妮·海瑟薇 Anne Hathaway 饰）、罗米利（大卫·吉雅西 David Gyasi 饰）、多伊尔（韦斯·本特利 Wes Bentley 饰）搭乘宇宙飞船前往目前已知的最有希望的三颗星球考察。
他们穿越遥远的星系银河，感受了一小时七年光阴的沧海桑田，窥见了未知星球和黑洞的壮伟与神秘。在浩瀚宇宙的绝望而孤独角落，总有一份超越了时空的笃定情怀将他们紧紧相连…… ©豆瓣

## 星际穿越的演职员 · · · · · · ( 全部 47 )

- 克里斯托弗·诺兰 导演
- 马修·麦康纳 饰 库珀 Cooper
- 安妮·海瑟薇 饰 布兰德 Brand
- 杰西卡·查斯坦 饰 墨菲(成年) Murph
- 麦肯吉·弗依 饰 墨菲(10岁) Murph (10 Yrs.)
- 卡西·阿弗莱克 饰 汤姆(成年) Tom

## 星际穿越的视频和图片 · · · · · · ( 预告片26 | 视频评论1 · 添加 | 图片2088 · 添加 )

## 星际穿越的获奖情况 · · · · · · ( 全部 )

- 第87届奥斯卡金像奖
- 最佳视觉效果
- 斯科特·R·费希尔 / 伊恩·亨特 / 保罗·J·富兰克林 / 安德鲁·洛克利

- 第72届金球奖
- 电影类 最佳原创配乐(提名)

- 第38届日本电影学院奖
- 最佳外语片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  盗梦空间

  黑客帝国

  阿凡达

  火星救援

  头号玩家

  源代码

  钢铁侠

  复仇者联盟

  X战警：逆转未来

  明日边缘

我要写短评

## 星际穿越的短评 · · · · · · ( 全部 417843 条 )

热门 / 最新 / 好友

### 46330 有用 一只野生叮当猫 看过 2014-11-11 00:03:39

诺兰说：如果我活得够长 那么豆瓣TOP250就被我承包了。

### 35379 有用 比岁月含蓄 看过 2014-11-06 23:27:12

时间可以伸缩和折叠，唯独不能倒退。你的鹤发或许是我的童颜，而我一次呼吸能抵过你此生的岁月。

### 3660 有用 同志亦凡人中文站 看过 2014-11-06 09:58:26

以地球全部北京化（咦？）为背景的近未来硬科幻，对虫洞、重力和时间维度都有新颖的理解，刻画的浩瀚宇宙让人目眩。可惜诺兰的野心太大（真的是bigger than bigger！），而且把人性拔那么高，到最后就成太空神棍片了...

### 2575 有用 桃桃林林 看过 2014-11-12 17:28:55

一边太空冒险，一边是通俗的情感戏。无论外表多硬科幻：虫洞、黑洞、太空冒险、多维空间……最核心的仍是亲情与爱。科学与理论其实都是为感情服务的，用很硬的外壳包裹最柔软的情感。也因为此，它不会是2001那样严肃伟大的科幻片，但却有更饱满的感情。包括那些泪点

### 20647 有用 影志 看过 2014-11-12 10:28:53

太壮阔了，无以言表！40'渐入佳境，80'叹为观止，120'泪流满面，160'恍如隔世…不曾如此贴近浩瀚星空，被它环抱；不曾如此触摸生命之弦，遁入五维幻境。瑕不掩瑜的科幻神作，刷新视觉的IMAX体验，观影前撒好尿，准备接受近三小时的泪腺洗礼。“爱是一种力量，让我们超越时空感知它的存在”-发自豆瓣App

> 更多短评 417843条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。

### 0 有用 黑烟的圈 看过 2020-08-13 11:30:46

什么鬼？脑洞太科学了不像脑洞。

我要写影评

## 星际穿越的影评 · · · · · · ( 全部 6349 条 )

热门 / 最新 / 好友
南极家暴观察员 2014-11-07 00:31:01

## 当你想描写一个触手可及的未来，然而却……

这篇影评可能有剧透

先推一篇视角独特的影评：被忽略的阿弗莱克 http://www.douban.com/note/450035111/ =================================== 图书管理员又在历史上留下了可歌可泣的一页。 五星只代表力荐，不代表满分。嫌这部电影不够硬的同学，不管你是文科生、理科生，还是特别特别厉害的、... (展开)
13554 459 910回应 收起
便便 2014-11-05 15:13:13

## Interstellar 观影感+全剧透+2刷发现果然没漏洞。。

11.4号70mm IMAX场，提前接近一个月就订好了票，连基友都没有带就准备一个人静静地观赏这场电影，免得到时候在回去的路上听人balabala说哪里不好看、又比不上哪部电影之类的废话。好吧，其实是因为基友品味太差，只喜欢R.I.P.D这种类型的片，实在提不起兴趣提前一个月订这种... (展开)
6606 1005 994回应 收起
更深的白色 2014-11-06 22:35:00

## 诺兰的维度

这篇影评可能有剧透

Spoiler Alert 在我们进入对“Interstellar”的具体讨论之前，也许需要对诺兰导演进行一个小小的总结和分析——他也许是我们这个时代最能兼具票房号召力和影迷人气的导演。如果我们抛开影视工业的层面，仅仅从个人才华上分析诺兰的成功，那么他最大的优点和长处在哪？或者说... (展开)
3734 717 688回应 收起
perceptor 2014-11-09 01:20:42

## 银河彼端，群星尽头

这篇影评可能有剧透

小时候居住的城市有着令人惊叹的重工业和灰黄色的天空，在夜晚，除了朦胧的月球，偶尔也只能一瞥天狼星和金星摇曳的身姿。第一次与银河的会面是在天文馆的投影穹幕里，外表奇异的投影仪冷静的转动，将无数光点铺满头顶。这固然比不上若干年后在海滨散步时与这条雄伟光带真身那... (展开)
2490 92 223回应 收起
刘伪冒 2014-05-02 16:37:42

## 科普黑洞虫洞，备战星际穿越

诺兰的新作「星际穿越」基于美国理论物理学家基普·索恩的理论成果，而他的理论成果基本都在他的著作「黑洞与时间弯曲」一书中，本文的科学知识基本都是我在这本著作中看到总结的。 该片剧情将涉很多的科学概念，包括虫洞、黑洞理论、相对论，万有引力等等。 一、黑洞 基帕... (展开)
2131 96 161回应 收起
黄青蕉 2014-11-18 19:51:59

## 如果要给星际穿越一个分级，我把它分为【逼级片】

最近诺兰粉真是越来越猖狂惹。 早先拍蝙蝠侠估计算借了现代名著的光，群众基础本来就广，红了也算不得百分百英雄好汉，就算前面还有记忆碎片，那也毕竟没有上过天朝院线，没有得过奥斯卡或者永远得不到奥斯卡的男神主演，更别提情节不照着豆瓣剧透贴掰开了揉碎了一帧帧回顾着... (展开)
1940 1034 427回应 收起
Granite Lee 2014-11-10 02:17:23

## Interstellar100%细节剧透，看完再来看剧透！！

这篇影评可能有剧透

已经有好多小伙伴写过剧透了，但是，楼主可是花了一夜时间吐血整理的100%细节剧情啊，请大家轻喷。。。 在不久的未来，人类面临着巨大的生存危机。地球资源枯竭，环境恶化，将无法维持人类的生存。因为枯萎病加剧，农作物难以维持其生存，粮食产量急剧下降。同时，世界环境恶... (展开)
1790 112 175回应 收起
Royce 2014-11-17 23:05:30

## Cooper的儿子，老农民汤姆才是救世主！

这篇影评可能有剧透

李硕：“决定我们行为的，终究是我们的情感。”——题记 诺兰新片一出，各路讨论纷纷聚焦在黑洞是啥、相对论咋回事、什么是五维空间等物理学原理上，文青影评家们终于找到了秀逼格的创新点，这时候要不懂平行宇宙你都不好意思上豆瓣，而理聪们给影片测bug的技能则更不... (展开)
1402 25 85回应 收起
艾小柯 2014-11-16 22:13:03

## 有关《星际穿越》的三个问题

这篇影评可能有剧透

1．科学的问题 诺兰的《星际空间》有两个细节非常打动我。一是Endurance太空站到达木星后准备进入虫洞，这个只在理论上存在的高维空间在银幕上的视觉展示是球体而不是一个平面化的隧道洞口。在“进入”的镜头系列中，Endurance并非抽象地“嗖”一下没入球体，而是缓步接近虫洞... (展开)
778 88 126回应 收起

> 更多影评 6349篇

添加新讨论

## 讨论区 · · · · · ·

唯一一部电影院四刷的电影 | 来自SunsetGlow | 5 回应 | 2022-11-24 21:54:35
为啥这么多人说星际穿越不好看 | 来自等待你的阿七 | 6 回应 | 2022-11-24 13:54:35
男主的容貌为什么一直停留在他出发前的样子？ | 来自张寒芷 | 3 回应 | 2022-11-23 01:52:09
在那个星球上一小时等于地球7年，那为啥人不会变老 | 来自夏 | 5 回应 | 2022-11-22 12:24:15
曼恩博士为什么一定要杀了库珀 | 来自文飘 | 4 回应 | 2022-11-22 09:53:12

> 去这部影片的讨论区（全部1610条）

## 关于《星际穿越》的问题 · · · · · · ( 全部1219个 )

- 库帕儿子这一角色在剧中是否多余？ 130人回答
- 请问男主角的老婆呢？ 26人回答

> 全部1219个问题

## 在哪儿看这部电影 · · · · · ·

报错

- 优酷视频 VIP免费观看
- 芒果TV VIP免费观看
- 爱奇艺视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【内牛满面】 (影志)
- {北美电影票房总排行} (荔枝超人)
- 数学、物理学生可能感兴趣的电影、纪录片 (傑)
- 曾经关于时空的豆列 (L.L)

## 谁在看这部电影 · · · · · ·

- Guofy
  1分钟前 看过
- 你家饭不好吃
  1分钟前 看过
- WANG
  1分钟前 看过

2807048人看过 / 395381人想看

订阅星际穿越的评论:
feed: rss 2.0